package com.ruoyi.system.controller;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ZbGc;
import com.ruoyi.system.service.IZbGcService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 招标网工程类爬虫Controller
 * 
 * @author peach
 * @date 2022-05-18
 */
@Controller
@RequestMapping("/system/gc")
public class ZbGcController extends BaseController
{
    private String prefix = "system/gc";

    @Autowired
    private IZbGcService zbGcService;

    @RequiresPermissions("system:gc:view")
    @GetMapping()
    public String gc()
    {
        return prefix + "/gc";
    }

    /**
     * 查询招标网工程类爬虫列表
     */
    @RequiresPermissions("system:gc:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(ZbGc zbGc)
    {
        startPage();
        List<ZbGc> list = zbGcService.selectZbGcList(zbGc);
        return getDataTable(list);
    }

    /**
     * 导出招标网工程类爬虫列表
     */
    @RequiresPermissions("system:gc:export")
    @Log(title = "招标网工程类爬虫", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(ZbGc zbGc)
    {
        List<ZbGc> list = zbGcService.selectZbGcList(zbGc);
        ExcelUtil<ZbGc> util = new ExcelUtil<ZbGc>(ZbGc.class);
        return util.exportExcel(list, "招标网工程类爬虫数据");
    }

    /**
     * 新增招标网工程类爬虫
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存招标网工程类爬虫
     */
    @RequiresPermissions("system:gc:add")
    @Log(title = "招标网工程类爬虫", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(ZbGc zbGc)
    {
        return toAjax(zbGcService.insertZbGc(zbGc));
    }

    /**
     * 修改招标网工程类爬虫
     */
    @RequiresPermissions("system:gc:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        ZbGc zbGc = zbGcService.selectZbGcById(id);
        mmap.put("zbGc", zbGc);
        return prefix + "/edit";
    }

    /**
     * 修改保存招标网工程类爬虫
     */
    @RequiresPermissions("system:gc:edit")
    @Log(title = "招标网工程类爬虫", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(ZbGc zbGc)
    {
        return toAjax(zbGcService.updateZbGc(zbGc));
    }

    /**
     * 删除招标网工程类爬虫
     */
    @RequiresPermissions("system:gc:remove")
    @Log(title = "招标网工程类爬虫", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(zbGcService.deleteZbGcByIds(ids));
    }
}
