package com.ruoyi.system.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.ruoyi.common.annotation.DataSource;
import com.ruoyi.common.enums.DataSourceType;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.ZbGcMapper;
import com.ruoyi.system.domain.ZbGc;
import com.ruoyi.system.service.IZbGcService;
import com.ruoyi.common.core.text.Convert;

/**
 * 招标网工程类爬虫Service业务层处理
 * 
 * @author peach
 * @date 2022-05-18
 */
@Service
@DataSource(value = DataSourceType.SLAVE)
public class ZbGcServiceImpl implements IZbGcService 
{
    @Autowired
    private ZbGcMapper zbGcMapper;


    @Override
    public List<Map<String,BigDecimal>> selectAllSumPriceByMon(String key) {
        return zbGcMapper.selectAllSumPriceByMon(key);
    }

    @Override
    public Map<String,Integer> getAllCount() {
        HashMap<String,Integer> hashMap=new HashMap();
        hashMap.put("clean",zbGcMapper.selectAllCount());
        hashMap.put("noClean", zbGcMapper.selectAllIsNull());
        hashMap.put("dirty", zbGcMapper.selectAllIsDirty());

        return hashMap;
    }

    @Override
    public List<Map<String, Integer>> getCleanCake() {
        List<Map<String, Integer>> list=new ArrayList<>();
      for (Map<String, Integer> zb:zbGcMapper.selectAllDoneByType()){
          list.add(zb);
      }

        for (Map<String, Integer> zb:zbGcMapper.selectAllNotDoneByType()){
            list.add(zb);
        }

        for (Map<String, Integer> zb:zbGcMapper.selectAllDirtyByType()){
            list.add(zb);
        }
        return list;


    }

    @Override
    public Map<String,List<Map<String, Integer>>> getCountByDepType(String key) {
        Map<String,List<Map<String, Integer>>> map=new HashMap<>();
        map.put("gs",zbGcMapper.selectAllZBCountByDepDateOne(key));
        map.put("dw",zbGcMapper.selectAllZBCountByDepDateTwo(key));
        return map;
    }

    @Override
    public Map<String,List<Map<String, Integer>>> getTypeByMon(String key) {
        Map<String,List<Map<String, Integer>>> map=new HashMap<>();
        map.put("gg",zbGcMapper.selectAllCountGGByMon(key));
        map.put("jg",zbGcMapper.selectAllCountJGByMon(key));
        return map;
    }



    @Override
    public List<Map<String, BigDecimal>> selectSumPriceByAddr() {
        List<String> list=zbGcMapper.selectAddrBySearchKey();
        List<Map<String, BigDecimal>> mapList=new ArrayList<>();
        for (String addr:list){
            mapList.add(zbGcMapper.selectSumPriceByAddr(addr));
        }
        return mapList;
    }


    /**
     * 查询招标网工程类爬虫
     * 
     * @param id 招标网工程类爬虫主键
     * @return 招标网工程类爬虫
     */
    @Override
    public ZbGc selectZbGcById(Long id)
    {
        return zbGcMapper.selectZbGcById(id);
    }

    /**
     * 查询招标网工程类爬虫列表
     * 
     * @param zbGc 招标网工程类爬虫
     * @return 招标网工程类爬虫
     */
    @Override
    public List<ZbGc> selectZbGcList(ZbGc zbGc)
    {
        return zbGcMapper.selectZbGcList(zbGc);
    }

    /**
     * 新增招标网工程类爬虫
     * 
     * @param zbGc 招标网工程类爬虫
     * @return 结果
     */
    @Override
    public int insertZbGc(ZbGc zbGc)
    {
        return zbGcMapper.insertZbGc(zbGc);
    }

    /**
     * 修改招标网工程类爬虫
     * 
     * @param zbGc 招标网工程类爬虫
     * @return 结果
     */
    @Override
    public int updateZbGc(ZbGc zbGc)
    {
        return zbGcMapper.updateZbGc(zbGc);
    }

    /**
     * 批量删除招标网工程类爬虫
     * 
     * @param ids 需要删除的招标网工程类爬虫主键
     * @return 结果
     */
    @Override
    public int deleteZbGcByIds(String ids)
    {
        return zbGcMapper.deleteZbGcByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除招标网工程类爬虫信息
     * 
     * @param id 招标网工程类爬虫主键
     * @return 结果
     */
    @Override
    public int deleteZbGcById(Long id)
    {
        return zbGcMapper.deleteZbGcById(id);
    }
}
